@@ -259,6 +259,16 @@ bpy.context.scene.render.resolution_percentage = params["resolution_percentage"]
 bpy.context.scene.frame_start = params["start_frame"]
 bpy.context.scene.frame_end = params["end_frame"]
 
+# Animation Speed (use Blender's time remapping to slow or speed up animation)
+animation_speed = int(params["animation_speed"])	# time remapping multiplier
+new_length = int(params["end_frame"]) * animation_speed	# new length (in frames)
+bpy.context.scene.frame_end = new_length
+bpy.context.scene.render.frame_map_old = 1
+bpy.context.scene.render.frame_map_new = animation_speed
+if params["start_frame"] == params["end_frame"]:
+	bpy.context.scene.frame_start = params["end_frame"]
+	bpy.context.scene.frame_end = params["end_frame"]
+
 # Render the current animation to the params["output_path"] folder
 bpy.ops.render.render(animation=params["animation"])
 
