@@ -265,6 +265,9 @@ class Bot():
 		# Create producer and initialize mlt
 		self.f = mlt.Factory().init()
 		self.p = mlt.Producer( self.profile, 'xml:%s' % self.file_name)
+		if self.p.is_valid() == False:
+			print "MLT producer failure"
+			sys.exit()
 		self.p.set_speed(0)
 		out_folder = self.render_options["folder"]
 		out_file = self.render_options["file"]
