@@ -50,10 +50,12 @@ class clip:
 		self.volume = 100.0
 		self.audio_fade_in = False
 		self.audio_fade_out = False
-		self.audio_fade_amount = 2.0
+		self.audio_fade_in_amount = 2.0
+		self.audio_fade_out_amount = 2.0
 		self.video_fade_in = False
 		self.video_fade_out = False
-		self.video_fade_amount = 2.0
+		self.video_fade_in_amount = 2.0
+		self.video_fade_out_amount = 2.0
 		self.parent = parent_track	  # the parent track this clip lives on
 		self.file_object = file_object  # the file object that this clip is linked to
 		self.unique_id = str(uuid.uuid1())
@@ -69,6 +71,12 @@ class clip:
 
 		# init effects dictionary
 		self.effects = []
+		
+		# init vars for drag n drop
+		self.drag_x = 0.0
+		self.drag_y = 0.0
+		self.moved = False
+		self.is_timeline_scrolling = False
 
 		# For example:  imagine a clip that is 30 seconds long.  If we wanted to only play a 10 second section (from 15 to 25 
 		# second range) of this clip, and we wanted the 10 second section to start playing 3 seconds into the tracks timeline, 
@@ -319,7 +327,7 @@ class clip:
 		else:
 			# only preview the trimmed clip
 			bg_image.length = self.length()
-		bg_image.max_frames = round(bg_image.length * fps)
+		bg_image.max_frames = round(bg_image.length * fps) - 1
 		bg_clip = clip("Background Clip", "Gold", 0.0, 0.0, bg_image.length, bg_track, bg_image)
 		bg_clip.distort = True
 		bg_clip.fill = True
@@ -415,6 +423,7 @@ class clip:
 		producer.setAttribute("novdpau", "1")
 		producer.setAttribute("in", str(int(round(in_frame_number))))
 		producer.setAttribute("out", str(int(round(out_frame_number))))
+		producer.setAttribute("length", str(int(round(out_frame_number) + 1)))
 
 		# hide video (if needed)
 		if self.play_video == False or self.parent.play_video == False:
@@ -501,50 +510,52 @@ class clip:
 
 		if self.has_audio():
 			# Only add volume nodes, if the clip might have audio
-			if self.play_audio == False or self.parent.play_audio == False:
-				# MUTE
-				filter = dom.createElement("filter")
-				filter.setAttribute("mlt_service", "volume")
-				filter.setAttribute("in", str(int(round(trans_in_frame_number))))
-				filter.setAttribute("out", str(int(round(trans_out_frame_number))))
-				filter.setAttribute("track", str(track_index_flipped))
-				filter.setAttribute("gain", locale.str(0))
-
-				# add volume filter to tractor
-				tractor_node.appendChild(filter)
-			else:
-
-				# any fade in?
-				if self.audio_fade_in:
-
-					# FADE IN
+			# ignore audio settings when previewing a clip
+			if preview_mode != "trimming":
+				if self.play_audio == False or self.parent.play_audio == False:
+					# MUTE
 					filter = dom.createElement("filter")
 					filter.setAttribute("mlt_service", "volume")
-					filter.setAttribute("in", str(int(round(current_audio_frame))))
-					if current_audio_frame + (self.audio_fade_amount * fps) <= trans_out_frame_number:
-						# ADD FADE AMOUNT
-						current_audio_frame = current_audio_frame + round(self.audio_fade_amount * fps)
-						filter.setAttribute("out", str(int(round(current_audio_frame))))
-					else:
-						# ADJUST FADE AMOUNT TO FIT SMALLER TIME
-						current_audio_frame = trans_out_frame_number
-						filter.setAttribute("out", str(int(round(current_audio_frame))))
+					filter.setAttribute("in", str(int(round(trans_in_frame_number))))
+					filter.setAttribute("out", str(int(round(trans_out_frame_number))))
 					filter.setAttribute("track", str(track_index_flipped))
 					filter.setAttribute("gain", locale.str(0))
-					filter.setAttribute("end", locale.str(self.volume / 100))
-
+	
 					# add volume filter to tractor
 					tractor_node.appendChild(filter)
+				else:
+	
+					# any fade in?
+					if self.audio_fade_in:
+	
+						# FADE IN
+						filter = dom.createElement("filter")
+						filter.setAttribute("mlt_service", "volume")
+						filter.setAttribute("in", str(int(round(current_audio_frame))))
+						if current_audio_frame + (self.audio_fade_in_amount * fps) <= trans_out_frame_number:
+							# ADD FADE AMOUNT
+							current_audio_frame = current_audio_frame + round(self.audio_fade_in_amount * fps)
+							filter.setAttribute("out", str(int(round(current_audio_frame))))
+						else:
+							# ADJUST FADE AMOUNT TO FIT SMALLER TIME
+							current_audio_frame = trans_out_frame_number
+							filter.setAttribute("out", str(int(round(current_audio_frame))))
+						filter.setAttribute("track", str(track_index_flipped))
+						filter.setAttribute("gain", locale.str(0))
+						filter.setAttribute("end", locale.str(self.volume / 100))
+	
+						# add volume filter to tractor
+						tractor_node.appendChild(filter)
 
 
 				# SET REGULAR VOLUME (length between the 2 fade volume nodes)
-				if self.audio_fade_out and current_audio_frame < (trans_out_frame_number - (self.audio_fade_amount * fps)):
+				if self.audio_fade_out and current_audio_frame < (trans_out_frame_number - (self.audio_fade_out_amount * fps)):
 					# MIDDLE TO FADE_OUT
 
 					filter = dom.createElement("filter")
 					filter.setAttribute("mlt_service", "volume")
 					filter.setAttribute("in", str(int(round(current_audio_frame))))
-					current_audio_frame = trans_out_frame_number - round(self.audio_fade_amount * fps)
+					current_audio_frame = trans_out_frame_number - round(self.audio_fade_out_amount * fps)
 					filter.setAttribute("out", str(int(round(current_audio_frame))))
 					filter.setAttribute("track", str(track_index_flipped))
 					filter.setAttribute("gain", locale.str(self.volume / 100))
@@ -737,7 +748,7 @@ class clip:
 				current_frame = end
 			elif self.video_fade_in:
 				# LEFT FADE IN
-				end = current_frame + round((self.video_fade_amount) * fps)
+				end = current_frame + round((self.video_fade_in_amount) * fps)
 				if end > end_frame:
 					end = end_frame
 				self.CreateCompositeXML(dom, current_frame, end, "fade in", fps=fps)
@@ -781,7 +792,7 @@ class clip:
 
 			elif self.video_fade_out:
 				# FADE OUT
-				begin_of_fade_out = end_frame - round(self.video_fade_amount * fps)
+				begin_of_fade_out = end_frame - round(self.video_fade_out_amount * fps)
 				if current_frame < begin_of_fade_out:
 					# add filler
 					self.CreateCompositeXML(dom, current_frame, begin_of_fade_out, "filler", fps=fps)
@@ -1161,7 +1172,7 @@ class clip:
 										      x = x + pixbuf_x,
 										      y = y)  
 					image2.set_data ("id", "small_middle")
-
+										
 					# Add a translucent blue rectangle
 					rec2 = goocanvas.Rect (parent = GroupClip,
 										   x = x + pixbuf_x,
@@ -1239,6 +1250,7 @@ class clip:
 					#self.get_canvas_child(item, "clip_name").set_properties(visibility = 1)
 					if self.effects:
 						self.get_canvas_child(item, "effect").set_properties(visibility = 1)
+					
 					# raise the clip text (since it can get hidden by other clip-related layers)
 					self.get_canvas_child(item, "clip_name").raise_(None)
 
@@ -1541,7 +1553,7 @@ class clip:
 
 		# get the new x,y coordinates from the mouse
 		new_x = float(event.x)
-		new_y = float(event.y)	
+		new_y = float(event.y)
 
 		# get the pixels per second from the parent sequence
 		pixels_per_second = self.parent.parent.get_pixels_per_second()
@@ -1549,10 +1561,13 @@ class clip:
 		# determine end pixel of sequence
 		end_of_timeline = self.parent.parent.length * pixels_per_second
 
-
 		# determine what cursor mode is enable (arrow, razor, snap, etc...)
 		(isArrow, isRazor, isSnap, isResize) = self.parent.parent.project.form.get_toolbar_options()
 
+		# determine if the timeline is being scrolled (with the middle mouse button)
+		if self.parent.parent.project.form.is_timeline_scrolling:
+			self.is_timeline_scrolling = True
+
 		# ARROW MODE
 		if isArrow:
 
@@ -1560,18 +1575,28 @@ class clip:
 			if (event.state & gtk.gdk.BUTTON1_MASK):
 
 				# don't allow the clip to slide past the beginning of the canvas
-				total_x_diff = new_x - self.drag_x 
+				total_x_diff = new_x - self.drag_x
 				total_y_diff = new_y - self.drag_y
 				if (item.get_bounds().x1 + total_x_diff < 0):
 					total_x_diff = 0.0 - float(item.get_bounds().x1)
 
 				# be sure that the clip is being dragged over a valid drop target (i.e. a track)
-				if self.is_valid_drop(item.get_bounds().x1 + total_x_diff, item.get_bounds().y1 + total_y_diff):
+				if self.get_valid_drop(item.get_bounds().x1 + total_x_diff, item.get_bounds().y1 + total_y_diff):
 					# mark project as modified
 					self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True)
+					self.moved = True
 
-					# move clip
-					item.translate (total_x_diff, total_y_diff)
+					# Determine CTRL snapping amount (if CTRL key is pressed)
+					if not self.parent.parent.project.form._CTRL:
+						
+						# move clip normally
+						item.translate (total_x_diff, total_y_diff)
+					
+					else:
+						# CTRL is pressed
+						# move clip vertically
+						item.translate (0, total_y_diff)
+				
 
 		# RESIZE MODE
 		if isResize:
@@ -1649,6 +1674,7 @@ class clip:
 
 						# mark project as modified
 						self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True)
+						self.moved = True
 
 						self.position_on_track = new_position
 						self.start_time = new_start_time
@@ -1680,6 +1706,7 @@ class clip:
 
 						# mark project as modified
 						self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True)
+						self.moved = True
 
 						# re-render this clip to the canvas (passing the canvas group to the RenderClip method)
 						self.RenderClip(item, x_offset, y_offset)
@@ -1728,6 +1755,11 @@ class clip:
 		# set the x and y where the cursor started dragging from
 		self.drag_x = float(event.x)
 		self.drag_y = float(event.y)
+		self.moved = False
+		self.is_timeline_scrolling = False
+		
+		# Do not show clip properties by default
+		self.request_show_properties = False
 
 		# only respond to the first mouse button
 		if event.button == 1:
@@ -1761,7 +1793,7 @@ class clip:
 					self.show_preview = False
 
 
-				if event.state & gtk.gdk.SHIFT_MASK:
+				if self.parent.parent.project.form._SHIFT:
 					# remove clip from goocanvas
 					parent = item.get_parent()
 					child_num = parent.find_child (item)
@@ -1771,21 +1803,14 @@ class clip:
 					self.parent.clips.remove(self)
 
 					# mark project as modified
-					self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True)
+					self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Removed clip"))
 
 				else:
 					# change the cursor for the drag n drop operation
 					fleur = gtk.gdk.Cursor (gtk.gdk.FLEUR)
 					canvas = item.get_canvas ()
-					self.stored_x = item.get_bounds().x1
-					self.stored_y = item.get_bounds().y1
 					canvas.pointer_grab (item, gtk.gdk.POINTER_MOTION_MASK | gtk.gdk.BUTTON_RELEASE_MASK, fleur, event.time)
 
-				if (event.state == gtk.gdk.CONTROL_MASK) or (event.state == gtk.gdk.CONTROL_MASK | gtk.gdk.MOD2_MASK):
-					self.request_show_properties = True
-				else:
-					self.request_show_properties = False
-
 
 			# RAZOR MODE
 			elif isRazor:
@@ -1827,6 +1852,11 @@ class clip:
 			elif isSnap:
 				pass
 
+		elif event.button == 2:
+
+			# show clip properties (middle mouse button)
+			self.request_show_properties = True
+
 		elif event.button == 3:
 			# show the track popup menu
 			self.parent.parent.project.form.mnuClip1.showmnu(event, self, item)
@@ -1902,7 +1932,8 @@ class clip:
 		parent.remove_child (child_num)
 
 		# Modify the 1st clip, and render it to the screen
-		self.end_time = (seconds_for_x - self.position_on_track) + self.start_time
+		first_length = seconds_for_x - self.position_on_track
+		self.end_time = self.start_time + first_length
 		self.RenderClip()
 
 		# calculate the 2nd clip properties
@@ -1924,10 +1955,12 @@ class clip:
 		SecondClip.volume = self.volume
 		SecondClip.audio_fade_in = self.audio_fade_in
 		SecondClip.audio_fade_out = self.audio_fade_out
-		SecondClip.audio_fade_amount = self.audio_fade_amount
+		SecondClip.audio_fade_in_amount = self.audio_fade_in_amount
+		SecondClip.audio_fade_out_amount = self.audio_fade_out_amount
 		SecondClip.video_fade_in = self.video_fade_in
 		SecondClip.video_fade_out = self.video_fade_out
-		SecondClip.video_fade_amount = self.video_fade_amount
+		SecondClip.video_fade_in_amount = self.video_fade_in_amount
+		SecondClip.video_fade_out_amount = self.video_fade_out_amount
 
 		# copy original properties
 		SecondClip.keyframes = copy.deepcopy(self.keyframes)
@@ -2015,7 +2048,7 @@ class clip:
 		elif distance_from_playhead != 0:
 			distance_from_clip = distance_from_playhead
 
-		# return the # of pixesl to snap the clip
+		# return the # of pixels to snap the clip
 		return distance_from_clip
 
 
@@ -2069,13 +2102,14 @@ class clip:
 				drop_track.reorder_clips()  
 
 				# determine the direction of the drag
-				if isSnap:
+				if isSnap and not self.parent.parent.project.form._CTRL:
+					# snap (if enabled) and if CTRL is not pressed
 					distance_from_clip = self.get_snap_difference(self, item)
 				else:
 					distance_from_clip = 0.0
 
 				# check if clip has been really moved or not
-				if ((self.stored_x == item.get_bounds().x1) and (self.stored_y == item.get_bounds().y1)):
+				if not self.moved:
 					# The clip was not moved
 					type_of_event = None
 				else:
@@ -2095,9 +2129,6 @@ class clip:
 					self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = type_of_event)
 
 
-				if self.request_show_properties:
-					self.show_properties(item, 0)
-
 		elif isResize:
 
 			# only respond to the first mouse button
@@ -2123,6 +2154,10 @@ class clip:
 				self.set_view_mode()
 				self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Resized clip"))
 
+		# Do we show the clip properties?
+		if self.request_show_properties and not self.moved and not self.is_timeline_scrolling:
+			self.show_properties(item, 0)
+
 		# raise the play-head line, so it's not covered up
 		self.parent.parent.raise_transitions()
 		self.parent.parent.play_head.raise_(None)
@@ -2134,30 +2169,7 @@ class clip:
 		# reset the cursor
 		self.parent.parent.project.form.MyCanvas.window.set_cursor(None)
 
-
-
-	def is_valid_drop(self, x1, y1):
-		""" Check to see if the current position is a valid drop position """
-
-		# loop through each track
-		for track in self.parent.parent.tracks:
-
-			# get the top y and bottom y of each track
-			y_top = track.y_top
-			y_bottom = track.y_bottom
-
-			# get the middle of the clip
-			half_height_of_clip = 26
-			middle_position = half_height_of_clip + y1
-
-			# determine if middle of clip is contained inside this track
-			if middle_position > y_top and middle_position < y_bottom:
-				return True
-
-		# return false if no valid track found
-		return False
-
-
+	
 	def get_valid_drop(self, x1, y1):
 		""" A clip must be dropped on a track.  This method returns the track 
 		object that is under the clip's current position """
@@ -2295,6 +2307,22 @@ class clip:
 			state['speed'] = 1.0
 		if 'rotation' not in state:
 			state['rotation'] = 0.0
+		if 'audio_fade_in_amount' not in state:
+			state['audio_fade_in_amount'] = 2.0
+		if 'audio_fade_out_amount' not in state:
+			state['audio_fade_out_amount'] = 2.0 
+		if 'video_fade_in_amount' not in state:
+			state['video_fade_in_amount'] = 2.0
+		if 'video_fade_out_amount' not in state:
+			state['video_fade_out_amount'] = 2.0
+		if 'drag_x' not in state:
+			state['drag_x'] = 0.0
+		if 'drag_y' not in state:
+			state['drag_y'] = 0.0
+		if 'moved' not in state:
+			state['moved'] = False
+		if 'is_timeline_scrolling' not in state:
+			state['is_timeline_scrolling'] = False			
 
 		# update the state object with new schema changes
 		self.__dict__.update(state)
