@@ -77,8 +77,8 @@ class effect:
 		# create effect node
 		filter_root = dom.createElement("filter")
 		filter_root.setAttribute("mlt_service", service)
-		filter_root.setAttribute("in", str(in_frame))
-		filter_root.setAttribute("out", str(out_frame))
+		filter_root.setAttribute("in", str(int(round(in_frame))))
+		filter_root.setAttribute("out", str(int(round(out_frame))))
 		filter_root.setAttribute("track", str(track))
 		
 		if not audio_effect:
