@@ -123,7 +123,7 @@ class OpenShotFile:
 			new_name = "thumbnail/" + file_base_name + "_" + ext + "_1.png"
 			
 			# Create the new thumbnail
-			thumbnailer.get_thumb_at_frame(self.name, new_name=new_name)
+			thumbnailer.get_thumb_at_frame(self.name, new_name=new_name, full_size=False)
 
 ########################################################################
 class OpenShotFolder:
@@ -408,7 +408,7 @@ class OpenShotFolder:
 
 		# check if this file is already in the project
 		for item in self.items:
-			if not is_part and item.file_type == _("Image Sequence").lower():
+			if not is_part and item.file_type == "image sequence":
 				(itemBase, itemExt) = os.path.split(item.name)
 				if new_folder_path == itemBase:
 					return True
@@ -477,8 +477,12 @@ class OpenShotFolder:
 			
 			if isinstance(item, OpenShotFile):
 				if item.file_type != "image sequence":
-					if os.path.samefile(file_name, item.name):
-						return True
+					try:
+						if os.path.samefile(file_name, item.name):
+							return True
+					except OSError:
+						print "Error checking files on import"
+						
 		
 		# didn't find a match
 		return False
