@@ -110,6 +110,11 @@ def check_pid(path):
 			print "Adding files to the watch queue:"
 			for arg in sys.argv[1:]:
 				
+				# a media file, add it to the project tree
+				# if the path isn't absolute, make it absolute
+				if not os.path.isabs(arg):
+					arg = os.path.abspath(arg)
+				
 				# ignore OSP project files
 				if ".osp" not in arg:
 					# print the path of the media file
