@@ -24,6 +24,13 @@ from language import Language_Init
 
 def get_response(*args):
 	
+	# look for extra parameters
+	parameters = None
+	for arg in args:
+		if type(arg) == dict:
+			parameters = arg
+			break
+	
 	# hide message dialog
 	args[0].destroy()
 
@@ -31,33 +38,59 @@ def get_response(*args):
 		# call callback function (if any)
 		if args[2]:
 			# call callback
-			args[2]()
+			if parameters:
+				args[2](parameters)
+			else:
+				args[2]()
 	elif args[1] == gtk.RESPONSE_NO:
 		# call callback function (if any)
 		if args[3]:
 			# call callback
-			args[3]()
+			if parameters:
+				args[3](parameters)
+			else:
+				args[3]()
 	else:
 		pass
 		
 
 # show an error message (i.e. gtkDialog)
-def show(title, error_message, buttons=gtk.BUTTONS_OK, yes_callback_function=None, no_callback_function=None, *args):
+def show(title, error_message, buttons=gtk.BUTTONS_OK, yes_callback_function=None, no_callback_function=None, dialog_type=gtk.MESSAGE_INFO, secondary_message=None, *args):
+
+	# parse out any dictionaries (needed for custom parameters)
+	button_list = []
+	parameters = None
+	buttonA = None
+	buttonB = None
+	for arg in args:
+		if not type(arg) == dict:
+			if buttonA == None:
+				buttonA = arg
+			elif buttonB == None:
+				buttonB = arg
+				button_list.append((buttonA, buttonB))
+				buttonA = None
+				buttonB = None
+		else:
+			parameters = arg
 
 	# create an error message dialog
 	dialog = gtk.MessageDialog(
 		parent		 = None,
 		flags		  = gtk.DIALOG_MODAL,
-		type		   = gtk.MESSAGE_INFO,
+		type		   = dialog_type,
 		buttons		= buttons,
 		message_format = error_message)
 	dialog.set_title(title)
-	dialog.add_buttons(*args)
+	dialog.format_secondary_text(secondary_message)
+	
+	for button in button_list:
+		dialog.add_button(button[0], button[1])
 	
 	if getIconPath("openshot"):
 		dialog.set_icon_from_file(getIconPath("openshot"))
 		
-	dialog.connect('response', get_response, yes_callback_function, no_callback_function)
+	dialog.connect('response', get_response, yes_callback_function, no_callback_function, parameters)
 	dialog.show()
 
 
