@@ -95,6 +95,26 @@ def open_project(project_object, file_path):
 		if missing_transitions:
 			messagebox.show("OpenShot", _("The following transition(s) no longer exist.") + "\n\n" + missing_transitions)
 		
+		# Recreate the thumbnail folder if it is missing
+		if not os.path.exists(project_object.folder + "/thumbnail"):
+			os.makedirs(project_object.folder + "/thumbnail")
+		
+		# Recreate missing thumbnails for files
+		for item in items:
+			if isinstance(item, files.OpenShotFile):
+				if not os.path.exists(item.thumb_location):
+					item.update_thumbnail()
+		
+		# Recreate missing thumbnails for clips
+		for sequence in project_object.sequences:
+			for track in sequence.tracks:
+				for clip in track.clips:
+					# Code to keep pre 1.4.0 .osp files compatible. May be removed later.
+					if not hasattr(clip, "thumb_location"):
+						clip.thumb_location = ""
+				
+					if not os.path.exists(clip.thumb_location) and not clip.file_object.file_type == "audio":
+						clip.update_thumbnail()
 		
 		# mark XML as refreshable
 		project_object.set_project_modified(is_modified=False, refresh_xml=True)
