@@ -75,8 +75,8 @@ class mlt_profiles:
 			if profile_name == p.description():
 				return p
 		
-		# load default profile object... incase no match was found
-		p = mlt.Profile("DV NTSC")
+		# load default profile object... if no match was found
+		p = mlt.Profile("DV/DVD NTSC")
 		
 		# return the profile
 		return p
@@ -95,7 +95,7 @@ class mlt_profiles:
 def main():
 	mlt_profiles1 = mlt_profiles()
 	profile_list = mlt_profiles1.get_profile_list()
-	mlt_profiles1.get_profile("DV NTSC")
+	mlt_profiles1.get_profile("DV/DVD NTSC")
 
 if __name__ == "__main__":
 	main()
