@@ -100,7 +100,7 @@ class project():
 			self.thumbnailer.start()
 			
 	def set_theme(self, folder_name):
-		""" Set the current theme and theme settings """ 
+		""" Set the current theme and theme settings """
 
 		# Set the theme, and load the theme settings
 		self.theme = folder_name
@@ -333,7 +333,7 @@ class project():
 		
 		# get preferences to see whether to save in binary or ascii form
 		from windows import preferences
-		self.file_type = preferences.Settings.general["project_file_type"]
+		self.file_type = "ascii"
 		
 		# call the save method
 		save_project.save_project(self, file_path)
