@@ -16,9 +16,9 @@
 #	You should have received a copy of the GNU General Public License
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
-import os, threading, time
+import os, threading, time, uuid
 from PIL import Image
-from classes import files, profiles
+from classes import files, profiles, messagebox
 
 try:
 	import mlt
@@ -53,15 +53,19 @@ class thumbnailer ( threading.Thread ):
 			self.thumbnail_path = ""
 			self.file_type = "video"
 			self.label = ""
+			self.unique_id = str(uuid.uuid1())	
 			project_path = self.project.folder
 			(dirName, fileName) = os.path.split(file_location)
 			(fileBaseName, fileExtension) = os.path.splitext(fileName)
 			fileExtension = fileExtension.replace(".", "")
-			actual_thumbnail_path = project_path + "/thumbnail/" + fileBaseName + "_" + fileExtension + "_1.png"
+			
+			
+			uniqueFileBaseName = self.unique_id
+			actual_thumbnail_path = project_path + "/thumbnail/" + uniqueFileBaseName + "_" + fileExtension + "_1.png"
 
 			if only_thumbnail:
 				# just get 1 thumbnail frame
-				self.thumbnail_path = project_path + "/thumbnail/" + fileBaseName + "_" + fileExtension + "_%d.png"
+				self.thumbnail_path = project_path + "/thumbnail/" + uniqueFileBaseName + "_" + fileExtension + "_%d.png"
 				
 				# set the profile
 				self.profile = mlt.Profile("quarter_ntsc")
@@ -84,13 +88,24 @@ class thumbnailer ( threading.Thread ):
 			if self.p.is_valid() == False:
 				return None
 			
+			# Check for invalid files - badly generated video files can have
+			# a length of 0 or -1, e.g. 
+			# https://bugs.launchpad.net/ubuntu/+source/openshot/+bug/927755, https://bugs.launchpad.net/kazam/+bug/925238
+			if self.p.get_length() < 1 or self.p.get_length() == 0x7fffffff:
+				return None
+			
+			# check the 'seekable' property
+			# If it is zero, then MLT is likely to have problems with this file.
+			if self.p.get("seekable") == '0':
+				messagebox.show(_("Warning!"), _("The file %s has properties that may prevent it working properly in OpenShot.\nYou may need to transcode it to another format.") % (self.file_name))
+				
 			# create the consumer
 			self.c = mlt.Consumer(self.profile, "avformat", self.thumbnail_path)
 
 			# set some consumer properties
 			self.c.set("real_time", 0)
 			self.c.set("vcodec", "png")
-
+			
 			# determine length of clip in seconds
 			producer_fps = float(self.p.get_fps())
 			first_frame = int(round(producer_fps * start_time))
@@ -136,13 +151,6 @@ class thumbnailer ( threading.Thread ):
 				is_image = True
 				self.file_type = "image"	
 
-			# determine if this is an image
-			#is_image = False
-			#if self.p.get_length() == 15000:
-				# images always have exactly 15000 frames
-				#is_image = True
-				#self.file_type = "image"
-				
 				# set the max length of the image to 300 seconds (i.e. 5 minutes)
 				max_frames = producer_fps * 300
 				
