@@ -18,6 +18,7 @@
 
 import os, uuid, locale
 import gtk, goocanvas
+import time
 
 ########################################################################
 class transition:
@@ -40,7 +41,26 @@ class transition:
 		# mask settings
 		self.type = type				# transition or mask
 		self.mask_value = mask_value	# 0.0 to 1.0
+		
+		# init vars for drag n drop
+		self.drag_x = 0.0
+		self.drag_y = 0.0
 
+	#----------------------------------------------------------------------
+	def __setstate__(self, state):
+		""" This method is called when an OpenShot project file is un-pickled (i.e. opened).  It can
+		    be used to update the structure of old classes, to make old project files compatable with
+		    newer versions of OpenShot. """
+
+		# Check for missing DEBUG attribute (which means it's an old project format)
+		if 'drag_x' not in state:
+			state['drag_x'] = 0.0
+		if 'drag_y' not in state:
+			state['drag_y'] = 0.0
+			
+		# update the state object with new schema changes
+		self.__dict__.update(state)
+		
 
 	def Render(self, exiting_item=None, x_offset = 0):
 
@@ -221,13 +241,25 @@ class transition:
 
 			# ARROW MODE
 			if isArrow:
+				
+				if self.parent.parent.project.form._SHIFT:
+					# remove transition from goocanvas
+					parent = item.get_parent()
+					child_num = parent.find_child (item)
+					parent.remove_child (child_num)
 
-				# change the cursor for the drag n drop operation
-				fleur = gtk.gdk.Cursor (gtk.gdk.FLEUR)
-				canvas = item.get_canvas ()
-				self.stored_x = item.get_bounds().x1
-				self.stored_y = item.get_bounds().y1
-				canvas.pointer_grab (item, gtk.gdk.POINTER_MOTION_MASK | gtk.gdk.BUTTON_RELEASE_MASK, fleur, event.time)
+					# remove transition from parent track
+					self.parent.transitions.remove(self)
+
+					# mark project as modified
+					self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Removed transition"))
+
+				else:
+
+					# change the cursor for the drag n drop operation
+					fleur = gtk.gdk.Cursor (gtk.gdk.FLEUR)
+					canvas = item.get_canvas ()
+					canvas.pointer_grab (item, gtk.gdk.POINTER_MOTION_MASK | gtk.gdk.BUTTON_RELEASE_MASK, fleur, event.time)
 
 			# RESIZE MODE
 			elif isResize:
@@ -235,8 +267,6 @@ class transition:
 				# remember the original length and position before resizing starts
 				self.original_length = self.length
 				self.original_start_pos = self.position_on_track
-				self.stored_x = item.get_bounds().x1
-				self.stored_y = item.get_bounds().y1
 
 			# SNAP MODE
 			elif isSnap:
@@ -289,9 +319,17 @@ class transition:
 
 				# mark project as modified
 				self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True)
-				# move clip
-				item.translate (total_x_diff, total_y_diff)
+				
 
+				# Determine CTRL snapping amount (if CTRL key is pressed)
+				if not self.parent.parent.project.form._CTRL:
+					# move transition
+					item.translate (total_x_diff, total_y_diff)
+					
+				else:
+					# CTRL is pressed
+					# move transition vertically
+					item.translate (0, total_y_diff)
 
 
 		# RESIZE MODE
@@ -399,9 +437,8 @@ class transition:
 		return True
 
 
-
-	def on_button_release_x (self, item, target, event):
-		""" This method drops a clip, and snaps the clip to the nearest valid track """
+	def drop_canvas_item(self, item):
+		""" Drop the canvas item, and snap and resize it if 'snapping' enabled. """
 
 		# Get theme settings
 		theme_settings = self.parent.parent.project.theme_settings.settings
@@ -410,10 +447,6 @@ class transition:
 		self.parent.parent.play_head.raise_(None)
 		self.parent.parent.play_head_line.raise_(None)
 
-		# get reference to the canvas, and stop dragging the item
-		canvas = item.get_canvas()
-		canvas.pointer_ungrab (item, event.time)
-
 		# determine what cursor mode is enable (arrow, razor, snap, etc...)
 		(isArrow, isRazor, isSnap, isResize) = self.parent.parent.project.form.get_toolbar_options()
 
@@ -424,6 +457,7 @@ class transition:
 			# get new parent track
 			drop_track = self.get_valid_drop(item.get_bounds().x1, item.get_bounds().y1)
 			bottom_y = 0
+			new_length = 0
 
 			if drop_track == None:
 				# keep old parent, if no track found
@@ -435,14 +469,14 @@ class transition:
 			# get the pixels per second from the parent sequence
 			pixels_per_second = self.parent.parent.get_pixels_per_second()
 
-			# deterime the direction of the drag
+			# determine the direction of the drag
 			if isSnap:
 				distance_from_clip = self.get_snap_difference(self, item)
 			else:
 				distance_from_clip = 0.0
 
 			# update the position 
-			self.position_on_track = float(item.get_bounds().x1 + distance_from_clip) / pixels_per_second
+			new_position_on_track = float(item.get_bounds().x1 + distance_from_clip) / pixels_per_second
 
 			# update the parent (the primary track)
 			self.update_parent(drop_track)
@@ -459,11 +493,41 @@ class transition:
 				# refresh image
 				self.change_direction_image(item)
 
-			# Animate the transition to it's new position
-			item.animate(distance_from_clip, bottom_y - item.get_bounds().y1, 1.0, 0.0, False, 200, 4, goocanvas.ANIMATE_FREEZE)
+				# Change length of transition (if snap is enabled)
+				track_index = self.parent.parent.tracks.index(self.parent)
+				bottom_track = None
+				if (track_index + 1) <= (len(self.parent.parent.tracks) - 1):
+					bottom_track = self.parent.parent.tracks[track_index + 1]
+				
+				# get distance from nearby clips (to the Right)
+				edges = []
+				edge_of_clip = self.get_edge_of_clip(new_position_on_track, "right", self.parent, 10.0)
+				if edge_of_clip:
+					edges.append(edge_of_clip)
+				if bottom_track:
+					edge_of_clip = self.get_edge_of_clip(new_position_on_track, "right", bottom_track, 10.0)
+					if edge_of_clip:
+						edges.append(edge_of_clip)
 
-			# move the clip object on the timeline to correct position (snapping to the y and x of the track)		
-			item.translate (distance_from_clip, bottom_y - item.get_bounds().y1)
+				# Change length
+				if edges:
+					if sorted(edges)[0] > new_position_on_track:
+						new_length = sorted(edges)[0] - new_position_on_track
+	
+						if distance_from_clip and self.length != new_length:
+							# re-render transition (at correct width)
+							self.length = new_length
+
+			# Set the new position
+			self.position_on_track = new_position_on_track
+
+			# remove old canvas item
+			parent = item.get_parent()
+			child_num = parent.find_child (item)
+			parent.remove_child (child_num)
+
+			# create new transition canvas item (possibly a bigger size)
+			item = self.Render(None, 0)
 
 		# Hide the length label (so it doesn't clutter the timeline)
 		text1 = self.get_canvas_child(item, "tran_text")
@@ -473,7 +537,7 @@ class transition:
 		self.parent.parent.project.form.MyCanvas.window.set_cursor(None)
 
 		# check if clip has been really moved or not
-		if self.stored_x == item.get_bounds().x1 and self.stored_y == item.get_bounds().y1 and not isResize:
+		if self.drag_x == item.get_bounds().x1 and self.drag_y == item.get_bounds().y1 and not isResize:
 			type_of_event = None
 		elif isResize:
 			type_of_event = _("Resized transition")
@@ -484,6 +548,15 @@ class transition:
 		self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = type_of_event )
 
 
+	def on_button_release_x (self, item, target, event):
+		""" This method drops a clip, and snaps the clip to the nearest valid track """
+
+		# get reference to the canvas, and stop dragging the item
+		canvas = item.get_canvas()
+		canvas.pointer_ungrab (item, event.time)
+
+		return self.drop_canvas_item(item)
+
 	def get_valid_drop(self, x1, y1):
 		""" A clip must be dropped on a track.  This method returns the track 
 		object that is under the clip's current position """
@@ -538,80 +611,47 @@ class transition:
 		closest_clip = None
 		distance_from_clip = 0.0
 		distance_from_left_clip = 0.0
-		distance_from_right_clip = 0.0
 		distance_from_playhead = 0.0
 
 		# determine the direction of the drag
-		direction = ""
-		if canvas_item.get_bounds().x1 < old_x:
-			direction = "left"
-		else:
-			direction = "right"
+		direction = "left"
 
 		# Look on TOP TRACK
 		# get distance from nearby clips (to the LEFT)
 		nearby_clip_left = self.get_edge_of_clip(canvas_item.get_bounds().x1 / pixels_per_second, "left", self.parent) * pixels_per_second
 		distance_from_left_clip = nearby_clip_left - canvas_item.get_bounds().x1
 
-		# get distance from nearby clips (to the RIGHT)
-		nearby_clip_right = self.get_edge_of_clip(canvas_item.get_bounds().x2 / pixels_per_second, "right", self.parent) * pixels_per_second
-		distance_from_right_clip = (nearby_clip_right + 1) - canvas_item.get_bounds().x2
-
 		# check bottom track (if any)
 		BOTTOM_distance_from_left_clip = 0.0
-		BOTTOM_distance_from_right_clip = 0.0
 		if bottom_track:
 			# BOTTOM TRACK
 			# get distance from nearby clips (to the LEFT)
 			BOTTOM_nearby_clip_left = self.get_edge_of_clip(canvas_item.get_bounds().x1 / pixels_per_second, "left", bottom_track) * pixels_per_second
 			BOTTOM_distance_from_left_clip = BOTTOM_nearby_clip_left - canvas_item.get_bounds().x1
 
-			# get distance from nearby clips (to the RIGHT)
-			BOTTOM_nearby_clip_right = self.get_edge_of_clip(canvas_item.get_bounds().x2 / pixels_per_second, "right", bottom_track) * pixels_per_second
-			BOTTOM_distance_from_right_clip = (BOTTOM_nearby_clip_right + 1) - canvas_item.get_bounds().x2
-
-
 		# distance from the play-head
 		playhead_time = clip_object.parent.parent.play_head_position
 		playhead_pixels = playhead_time * pixels_per_second
 		distance_from_playhead = playhead_pixels - canvas_item.get_bounds().x1
 
-#		print "----------------"
-#		print "distance_from_left_clip: %s" % distance_from_left_clip
-#		print "distance_from_right_clip: %s" % distance_from_right_clip
-#		print "BOTTOM_distance_from_left_clip: %s" % BOTTOM_distance_from_left_clip
-#		print "BOTTOM_distance_from_right_clip: %s" % BOTTOM_distance_from_right_clip
-#		print "distance_from_playhead: %s" % distance_from_playhead
-
 		# limit the left /right snapping to 10 pixels
 		if distance_from_left_clip > 10 or distance_from_left_clip < -10:
 			distance_from_left_clip = 0.0
-		if distance_from_right_clip > 10 or distance_from_right_clip < -10:
-			distance_from_right_clip = 0.0
 		if BOTTOM_distance_from_left_clip > 10 or BOTTOM_distance_from_left_clip < -10:
 			BOTTOM_distance_from_left_clip = 0.0
-		if BOTTOM_distance_from_right_clip > 10 or BOTTOM_distance_from_right_clip < -10:
-			BOTTOM_distance_from_right_clip = 0.0
 		if distance_from_playhead > 10 or distance_from_playhead < -10:
 			distance_from_playhead = 0.0
 
 		# determine which direction and what clip to snap to (based on the direction the clip is moving)
 		if direction == "left" and distance_from_left_clip != 0:
 			distance_from_clip = distance_from_left_clip
+			
 		if direction == "left" and BOTTOM_distance_from_left_clip != 0:
 			distance_from_clip = BOTTOM_distance_from_left_clip
-		elif direction == "right" and distance_from_right_clip != 0:
-			distance_from_clip = distance_from_right_clip
-		elif direction == "right" and BOTTOM_distance_from_right_clip != 0:
-			distance_from_clip = BOTTOM_distance_from_right_clip
 		elif distance_from_left_clip != 0:
 			distance_from_clip = distance_from_left_clip
-		elif distance_from_right_clip != 0:
-			distance_from_clip = distance_from_right_clip
 		elif BOTTOM_distance_from_left_clip != 0:
 			distance_from_clip = BOTTOM_distance_from_left_clip
-		elif distance_from_right_clip != 0:
-			distance_from_clip = distance_from_right_clip
 		elif distance_from_playhead != 0:
 			distance_from_clip = distance_from_playhead
 
@@ -619,7 +659,7 @@ class transition:
 		return distance_from_clip
 
 
-	def get_edge_of_clip(self, current_position, direction, track): 
+	def get_edge_of_clip(self, current_position, direction, track, threashold=1.0): 
 		""" Get the position of the closest edge of a track """
 
 		if direction == "left":
@@ -629,8 +669,8 @@ class transition:
 				# get right edge of clip
 				next_edge = float(clip.position_on_track)
 
-				# if clip within 1/2 second distance
-				if abs(current_position - next_edge) <= 1.0:
+				# if clip within 1 second distance
+				if abs(current_position - next_edge) <= threashold:
 					edge = next_edge
 					break
 
@@ -644,8 +684,8 @@ class transition:
 				# get right edge of clip
 				next_edge = float(clip.position_on_track) + float(clip.length())
 
-				# if clip within 1/2 second distance 
-				if abs(current_position - next_edge) <= 1.0:
+				# if clip within 1 second distance 
+				if next_edge > current_position and abs(current_position - next_edge) <= threashold:
 					edge = next_edge
 					break
 
@@ -689,16 +729,17 @@ class transition:
 		# loop through clips on the BOTTOM track
 		BOTTOM_left_position = 0.0
 		BOTTOM_found = False
-		for clip in bottom_track.clips:
-			# get right edge of clip
-			clip_start = float(clip.position_on_track)
-			clip_end = float(clip.position_on_track + clip.length())
-
-			# does clip overlap transition
-			if (clip_end >= transition_start and clip_end <= transition_end) or (clip_start >= transition_start and clip_start <= transition_end) or (clip_start >= transition_start and clip_end <= transition_end) or (clip_start <= transition_start and clip_end >= transition_end):
-				BOTTOM_found = True
-				BOTTOM_left_position = clip_start
-				break
+		if bottom_track:
+			for clip in bottom_track.clips:
+				# get right edge of clip
+				clip_start = float(clip.position_on_track)
+				clip_end = float(clip.position_on_track + clip.length())
+	
+				# does clip overlap transition
+				if (clip_end >= transition_start and clip_end <= transition_end) or (clip_start >= transition_start and clip_start <= transition_end) or (clip_start >= transition_start and clip_end <= transition_end) or (clip_start <= transition_start and clip_end >= transition_end):
+					BOTTOM_found = True
+					BOTTOM_left_position = clip_start
+					break
 
 		if TOP_found == True and BOTTOM_found == True:
 			if TOP_left_position <= BOTTOM_left_position:
