@@ -70,6 +70,8 @@ def cell_edited(cell, row, new_text, model, project=None):
 	#set the edit in the model
 	model.set(iter,3,new_text)
 	#update the file object with the label edit
-	filename = model.get_value(iter, 1)
-	project.project_folder.UpdateFileLabel(filename, new_text, 0)
+	#filename = model.get_value(iter, 1)
+	#project.project_folder.UpdateFileLabel(filename, new_text, 0)
+	unique_id = model.get_value(iter, 4)
+	project.project_folder.UpdateFileLabel(unique_id, new_text, 0)
 	
