@@ -149,9 +149,15 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 		
 		# get the frame number
 		frame_number = int(widget.get_value())
+		length = int(self.params["end_frame"])
+		
+		# Get the animation speed (if any)
+		if self.params["animation_speed"]:
+			# Adjust length (based on animation speed multiplier)
+			length *= int(self.params["animation_speed"])
 
 		# Update preview label
-		self.lblFrame.set_text("%s/%s" % (frame_number, self.params["end_frame"]))
+		self.lblFrame.set_text("%s/%s" % (frame_number, length))
 		
 		# Render only the selected frame
 		if not self.is_rendering:
@@ -167,7 +173,7 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 		# get selected effect (if any)
 		selected_effect, unique_id = self.get_selected_effect()
 		real_effect = self.OSTreeBlender.get_real_effect(service=selected_effect)
-		
+
 		if real_effect:
 			
 			# get the selected template .blend name
@@ -235,7 +241,34 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 					textbox.connect("changed", self.effect_text_changed, real_effect, param, unique_id)
 					# add to hbox
 					hbox.pack_start(textbox, expand=True, fill=True)
-				
+					
+				elif param.type == "multiline":
+					# add value to dictionary
+					self.params[param.name] = param.default
+					
+					# create new scrolled window
+					scrolled_win = gtk.ScrolledWindow()
+					scrolled_win.set_shadow_type("in")
+					scrolled_win.set_property("hscrollbar_policy", "automatic")
+					scrolled_win.set_property("height-request", 100)
+					
+					# create buffer
+					new_buffer = gtk.TextBuffer()
+					new_buffer.set_text(param.default.replace("\\n","\n"))
+
+					# create spinner
+					textbox = gtk.TextView()
+					textbox.set_buffer(new_buffer)
+					#textbox.set_size_request(width=-1, height=75)
+					#textbox.set_property("height-request", 100)
+					textbox.set_wrap_mode("word")
+					
+					# connect signal 
+					new_buffer.connect("changed", self.effect_multi_text_changed, real_effect, param, unique_id)
+					# add to hbox
+					scrolled_win.add_with_viewport(textbox)
+					hbox.pack_start(scrolled_win, expand=True, fill=True)
+
 				elif param.type == "dropdown":
 					# add value to dictionary
 					self.params[param.name] = param.default
@@ -303,25 +336,36 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 				# increment param index
 				param_index = param_index + 1
 				
-			# Get current preview slider frame
-			preview_frame_number = int(self.sliderPreview.get_value())
-
-			# Update the preview slider
-			preview_adjustment = self.sliderPreview.get_adjustment()
-			length = (self.params["end_frame"] - self.params["start_frame"]) + 1
-			middle_frame = int(length / 2)
-			# Be sure the new 'middle frame' and the current preview frame are not the same
-			# This causes the thumbnail to refresh.
-			if preview_frame_number == middle_frame:
-				middle_frame += 1
-			preview_adjustment.set_lower(self.params["start_frame"])
-			preview_adjustment.set_upper(self.params["end_frame"] + 10)
-			preview_adjustment.set_value(middle_frame)
-			self.sliderPreview.set_adjustment(preview_adjustment)
+			# Init preview slider
+			self.init_slider_values()
 			
-			# Update preview label
-			self.lblFrame.set_text("%s/%s" % (middle_frame, self.params["end_frame"]))
-				
+	def init_slider_values(self):
+		
+		# Get current preview slider frame
+		preview_frame_number = int(self.sliderPreview.get_value())
+		length = int(self.params["end_frame"])
+		
+		# Get the animation speed (if any)
+		if not self.params["animation_speed"]:
+			self.params["animation_speed"] = 1
+		else:
+			# Adjust length (based on animation speed multiplier)
+			length *= int(self.params["animation_speed"])
+
+		# Update the preview slider
+		preview_adjustment = self.sliderPreview.get_adjustment()
+		middle_frame = int(length / 2)
+		# Be sure the new 'middle frame' and the current preview frame are not the same
+		# This causes the thumbnail to refresh.
+		if preview_frame_number == middle_frame:
+			middle_frame += 1
+		preview_adjustment.set_lower(self.params["start_frame"])
+		preview_adjustment.set_upper(length + 10)
+		preview_adjustment.set_value(middle_frame)
+		self.sliderPreview.set_adjustment(preview_adjustment)
+		
+		# Update preview label
+		self.lblFrame.set_text("%s/%s" % (middle_frame, length))
 				
 	def effect_dropdown_changed(self, widget, real_effect, param, *args):
 		print "effect_dropdown_changed"
@@ -334,6 +378,10 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 				
 		# Update the param of the selected effect
 		self.params[param.name] = dropdown_value
+		
+		# Adjust preview slider (if animation speed changes)
+		if param.name == "animation_speed":
+			self.init_slider_values()
 				
 	def effect_spinner_changed(self, widget, real_effect, param, *args):
 		print "effect_spinner_changed"
@@ -342,11 +390,20 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 		self.params[param.name] = float(widget.get_value())
 		
 	def effect_text_changed(self, widget, real_effect, param, *args):
-		print "effect_spinner_changed"
+		print "effect_text_changed"
 		
 		# Update the param of the selected effect
 		self.params[param.name] = widget.get_text()
 		
+	def effect_multi_text_changed(self, buffer, real_effect, param, *args):
+		print "effect_multi_text_changed"
+		
+		start, end = buffer.get_bounds()
+		updated_text = buffer.get_text(start, end)
+		
+		# Update the param of the selected effect
+		self.params[param.name] = updated_text.replace("\n", "\\n")
+		
 	def effect_color_changed(self, widget, real_effect, param, *args):
 		print "effect_color_changed"
 		
@@ -498,20 +555,17 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 		f.close()
 		
 	def update_progress_bar(self, current_frame, current_part, max_parts):
-		#print "update_progress_bar"
-		
+
 		# update label and preview slider
 		self.sliderPreview.set_value(float(current_frame))
 		
 		# determine length of image sequence
-		start_frame = int(self.params["start_frame"])
-		end_frame = int(self.params["end_frame"]) + 1
-		length = end_frame - start_frame
+		length = int(self.params["end_frame"])
 		
-		if start_frame > 1:
-			# adjust the current frame so it starts at 1
-			current_frame = int(current_frame) - (start_frame - 1)
-			print "... adjusted current frame"
+		# Get the animation speed (if any)
+		if self.params["animation_speed"]:
+			# Adjust length (based on animation speed multiplier)
+			length *= int(self.params["animation_speed"])
 		
 		# calculate the current percentage, and update the progress bar
 		progress = float(float(current_frame) / float(length))
@@ -600,8 +654,9 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 			version_message = _("\n\nError Output:\n%s") % command_output
 		
 		# show error message
-		messagebox.show(_("Blender Error"), _("Blender, the free open source 3D content creation suite is required for this action (http://www.blender.org).\n\nPlease check the preferences in OpenShot and be sure the Blender executable is correct.  This setting should be the path of the 'blender' executable on your computer.  Also, please be sure that it is pointing to Blender version 2.56 or greater.\n\nBlender Path:\n%s%s") % (self.form.settings.general["blender_command"], version_message))
-		
+		blender_version = "2.62"
+		messagebox.show(_("Blender Error"), _("Blender, the free open source 3D content creation suite is required for this action (http://www.blender.org).\n\nPlease check the preferences in OpenShot and be sure the Blender executable is correct.  This setting should be the path of the 'blender' executable on your computer.  Also, please be sure that it is pointing to Blender version %s or greater.\n\nBlender Path:\n%s%s") % (blender_version, self.form.settings.general["blender_command"], version_message))
+
 		# Enable the Render button again
 		self.btnRender.set_sensitive(True)
 
@@ -633,27 +688,28 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 			shutil.copy(child_source_full, child_target_full)
 			
 		# determine length of image sequence
-		start_frame = int(self.params["start_frame"])
-		end_frame = int(self.params["end_frame"])
-		length = end_frame - start_frame
+		length = int(self.params["end_frame"])
+		
+		# Get the animation speed (if any)
+		if self.params["animation_speed"]:
+			# Adjust length (based on animation speed multiplier)
+			length *= int(self.params["animation_speed"])
 			
 		# add file to current project
-		#f = self.project.project_folder.AddFile(first_image, ignore_image_sequences=True)
 		f = self.project.thumbnailer.GetFile(first_image)
-		
 		if f:
 			self.project.project_folder.items.append(f)
 			
 		# mark project as modified
 		self.project.set_project_modified(is_modified=True, refresh_xml=False, type=_("Added file"))
-			
+
 		# Update the file properties (since it's added as an image)
 		# We need to make it look like a video
 		f.label = _("Image Sequence")
 		f.fps = self.project.fps()
 		f.max_frames = length
 		f.ttl = 1.0
-		f.length = float(f.max_frames * f.ttl) / float(f.fps)
+		f.length = (float(f.max_frames) / float(f.fps)) - 0.01	# Subtract a 10th of a second, to prevent rounding errors
 		f.file_type = "image sequence"
 		f.name = os.path.join(target_folder, self.params["file_name"] + r"%04d.png")
 
@@ -662,8 +718,11 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 		
 				
 	def Render(self, frame=None):
-		""" Render an images sequence of the current template using Blender 2.56+ and the
+		""" Render an images sequence of the current template using Blender 2.62+ and the
 		Blender Python API. """
+		
+		# change cursor to "please wait"
+		self.frm3dGenerator.window.set_cursor(gtk.gdk.Cursor(150))
 
 		blend_file_path = os.path.join(self.project.BLENDER_DIR, "blend", self.selected_template)
 		source_script = os.path.join(self.project.BLENDER_DIR, "scripts", self.selected_template.replace(".blend", ".py"))
@@ -698,7 +757,6 @@ class BlenderCommand(threading.Thread):
 		
 		# get the blender executable path
 		self.blender_exec_path = frm3dGenerator.form.settings.general["blender_command"]
-		#self.blender_exec_path = "/home/jonathan/blender-2.5-alpha2-linux-glibc27-x86_64/blender"
 		self.blender_frame_expression = re.compile(r"Fra:([0-9,]*).*Mem:(.*?) .*Part ([0-9,]*)-([0-9,]*)")
 		self.blender_saved_expression = re.compile(r"Saved: (.*?) Time: (.*)")
 		self.blender_version = re.compile(r"Blender (.*?) ")
@@ -740,8 +798,12 @@ class BlenderCommand(threading.Thread):
 			self.version = self.blender_version.findall(self.process.stdout.readline())
 
 			if self.version:
-				if float(self.version[0]) < 2.56:
-					# Wrong version of Blender.  Must be 2.56+:
+				if float(self.version[0]) < 2.62:
+					# change cursor to "default" and stop running blender command
+					gobject.idle_add(self.frm3dGenerator.frm3dGenerator.window.set_cursor, None)
+					self.is_running = False
+					
+					# Wrong version of Blender.  Must be 2.62+:
 					gobject.idle_add(self.frm3dGenerator.error_with_blender, float(self.version[0]))
 					return
 			
@@ -753,7 +815,12 @@ class BlenderCommand(threading.Thread):
 			
 		except:
 			# Error running command.  Most likely the blender executable path in the settings
-			# is not correct, or is not the correct version of Blender (i.e. 2.56+)
+			# is not correct, or is not the correct version of Blender (i.e. 2.62+)
+			
+			# change cursor to "default" and stop running blender command
+			gobject.idle_add(self.frm3dGenerator.frm3dGenerator.window.set_cursor, None)
+			self.is_running = False
+			
 			gobject.idle_add(self.frm3dGenerator.error_with_blender)
 			return
 
@@ -795,6 +862,9 @@ class BlenderCommand(threading.Thread):
 			if line == '' and self.process.poll() != None:
 				break
 
+				
+		# change cursor to "default"
+		gobject.idle_add(self.frm3dGenerator.frm3dGenerator.window.set_cursor, None)
 
 		# Check if NO FRAMES are detected
 		if not self.frame_detected:
