@@ -17,18 +17,18 @@
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
 import os, gtk
-import gtk, gtk.glade
+import gtk
 from classes import messagebox, project
-from windows.SimpleGladeApp import SimpleGladeApp
+from windows.SimpleGtkBuilderApp import SimpleGtkBuilderApp
 
 # init the foriegn language
 import language.Language_Init as Language_Init
 
 
-class frmOpenProject(SimpleGladeApp):
+class frmOpenProject(SimpleGtkBuilderApp):
 
-	def __init__(self, path="OpenProject.glade", root="frmOpenProject", domain="OpenShot", project=None, **kwargs):
-		SimpleGladeApp.__init__(self, os.path.join(project.GLADE_DIR, path), root, domain, **kwargs)
+	def __init__(self, path="OpenProject.ui", root="frmOpenProject", domain="OpenShot", project=None, **kwargs):
+		SimpleGtkBuilderApp.__init__(self, os.path.join(project.UI_DIR, path), root, domain, **kwargs)
 
 		self.project = project
 		self.form = self.project.form
