@@ -53,6 +53,8 @@ class frmTransitionProperties(SimpleGtkBuilderApp):
 		
 		# init the project type properties
 		self.lblName.set_text(self.current_transition.name)
+		self.spinbtnStart.set_value(round(self.current_transition.position_on_track, 2))
+		self.spinbtnLength.set_value(round(self.current_transition.length , 2))
 		self.hsSoftness.set_value(self.current_transition.softness * 100.0)
 		self.hsThreshold.set_value(self.current_transition.mask_value)
 		
@@ -158,8 +160,30 @@ class frmTransitionProperties(SimpleGtkBuilderApp):
 		else:
 			self.hsThreshold.set_sensitive(True)
 
+	def on_spinbtnStart_value_changed(self, widget, *args):
+		"""Prevents any part of the transition to go outside the timeline.
+		A transition outside the timeline is a worthless transition."""
+	
+		start = self.spinbtnStart.get_value()
+		length = self.spinbtnLength.get_value()
+		end = start + length
+		timeline_length = self.project.sequences[0].length
 		
+		if end > timeline_length:
+			self.spinbtnStart.set_value(timeline_length - length)
+	
+	def on_spinbtnLength_value_changed(self, widget, *args):
+		"""Prevents any part of the transition to go outside the timeline.
+		A transition outside the timeline is a worthless transition."""
+	
+		start = self.spinbtnStart.get_value()
+		length = self.spinbtnLength.get_value()
+		end = start + length
+		timeline_length = self.project.sequences[0].length
 		
+		if end > timeline_length:
+			self.spinbtnLength.set_value(timeline_length - start)
+	
 	def on_btnCancel_clicked(self, widget, *args):
 		print "on_btnCancel_clicked"
 		self.frmTransitionProperties.destroy()
@@ -172,11 +196,17 @@ class frmTransitionProperties(SimpleGtkBuilderApp):
 		_ = self._
 		
 		# Get settings
+		localStart = self.spinbtnStart.get_value()
+		localLength = self.spinbtnLength.get_value()
 		localcboType = self.cboType.get_active_text()
 		localcboDirection = self.cboDirection.get_active_text().lower()
 		localhsSoftness = self.hsSoftness.get_value()
 		localhsThreshold = self.hsThreshold.get_value()
 		
+		# update position and length
+		self.current_transition.position_on_track = localStart
+		self.current_transition.length = localLength
+		
 		# update transition object
 		if localcboType.lower() == _("Mask").lower():
 			self.current_transition.type = "mask"
@@ -190,7 +220,7 @@ class frmTransitionProperties(SimpleGtkBuilderApp):
 		self.current_transition.mask_value = localhsThreshold
 		
 		# mark project as modified
-		self.project.set_project_modified(is_modified=True, refresh_xml=True)
+		self.project.set_project_modified(is_modified=True, refresh_xml=True, type = self._("Modified transition properties"))
 		
 		# Refresh the MLT XML file
 		self.project.RefreshXML()
