@@ -277,7 +277,7 @@ class PreferencesMgr(SimpleGtkBuilderApp):
 		theme_name = self.cmbThemes.get_active_text()
 		
 		# update theme on main form
-		self.form.project.theme = theme_name
+		self.form.project.set_theme(theme_name)
 		self.form.update_icon_theme()
 		self.form.refresh()
 
